locals {
  vpn_gateway_id     = var.connect_to_transit_gateway ? null : var.vpc_vgw_id
  transit_gateway_id = var.connect_to_transit_gateway ? var.transit_gateway_id : null

  prefix = var.connect_to_transit_gateway ? "${var.prefix}-tgw" : "${var.prefix}-vpn"

  common_tags = merge(var.tags, var.additional_tags)
}

#############
# VPN Gateway
#############
module "vpn_gateway" {
  source = "terraform-aws-modules/vpn-gateway/aws"
  version = "2.5.0"

  vpn_connection_static_routes_only         = var.vpn_connection_static_routes_only
  vpn_connection_static_routes_destinations = var.static_private_routes


  connect_to_transit_gateway = var.connect_to_transit_gateway
  transit_gateway_id  = local.transit_gateway_id
  vpn_gateway_id      = local.vpn_gateway_id

  customer_gateway_id = aws_customer_gateway.main.id

  vpc_id                       = var.vpc_id
  vpc_subnet_route_table_ids   = var.vpc_subnet_route_table_ids
  vpc_subnet_route_table_count = var.vpc_subnet_route_table_count

  tunnel1_inside_cidr = var.tunnel1_inside_cidr
  tunnel2_inside_cidr = var.tunnel2_inside_cidr
  tunnel1_preshared_key = var.tunnel1_preshared_key
  tunnel2_preshared_key = var.tunnel2_preshared_key

  # Add tags to resource, to add additional tags, define an additional_tags variable in your terraform.tfvars file
  tags = merge(
    local.common_tags,
    {
      Name = "${local.prefix}-main",
      IneName = var.gateway_ine_name
    }
  )
}

##################
# Customer Gateway
##################
resource "aws_customer_gateway" "main" {
  bgp_asn    = var.bgp_asn
  ip_address = var.customer_gateway_ip_address
  type       = var.type

  # Add tags to resource, to add additional tags, define an additional_tags variable in your terraform.tfvars file
  tags = merge(
    local.common_tags,
    {
      Name = "${local.prefix}-main",
      IneName = var.customer_gateway_ine_name
    }
  )
}
