# ------------------------
# TERRAGRUNT CONFIGURATION
# ------------------------

terraform {
    source = "git::git@github.com:company/terraform-modules.git//aws/networking/vpc/vpn/single?ref=v9.0.6"
}

# Include all settings from the root terraform.tfvars file
include {
    path = find_in_parent_folders()
}

dependency "vpc" {
    config_path = "../../connection"
}

dependency "tgw" {
    config_path = "../../transit-gateway"
}

prevent_destroy = false

# -------------------------------------------------------
# MODULE PARAMETERS
# These are the variables we have to pass in to use the
# module specifieid in the terragrunt configuration above
# -------------------------------------------------------
inputs = {
    prefix = "azure-hybrid-cloud-demo"

    vpc_id = dependency.vpc.outputs.vpc_id
    vpc_subnet_route_table_ids = dependency.vpc.outputs.private_route_table_ids
    vpc_subnet_route_table_count = length(dependency.vpc.outputs.private_subnets)

    transit_gateway_id = dependency.tgw.outputs.ec2_transit_gateway_id

    # use the TGW for this connection
    connect_to_transit_gateway = true
    vpn_connection_static_routes_only = true

    tunnel1_preshared_key = "********"

    static_private_routes = [
        "10.1.7.0/24"
    ]

    ##################
    # Customer Gateway
    ##################
    customer_gateway_ip_address = "127.0.0.1"
    customer_gateway_ine_name = "Azure Hybrid Cloud Demo"
    gateway_ine_name = "Azure Hybrid Cloud Demo"
}
